## v1.0.1 (2024-10-25)

### Fix

- properly handle breaking changes ([ef54285](https://github.com/kmnhan/cz-changeup/commit/ef5428575e24effa2c2fec8efccabef161274868))

[main e2ad449] bump: version 1.0.0 → 1.0.1
 2 files changed, 7 insertions(+), 1 deletion(-)

